==> zio-aws-s3control_3-5.17.146.2-sources.jar: zio/aws/s3control/model/GetAccessPointPolicyForObjectLambdaResponse.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.s3control.model.primitives.ObjectLambdaPolicy
import scala.jdk.CollectionConverters.*
final case class GetAccessPointPolicyForObjectLambdaResponse(
    policy: Option[ObjectLambdaPolicy] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse = {
    import GetAccessPointPolicyForObjectLambdaResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
      .builder()
      .optionallyWith(
        policy.map(value => ObjectLambdaPolicy.unwrap(value): java.lang.String)
      )(_.policy)
      .build()
  }
  def asReadOnly
      : zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse.ReadOnly =
    zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
      .wrap(buildAwsValue())
}
object GetAccessPointPolicyForObjectLambdaResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse =
      zio.aws.s3control.model
        .GetAccessPointPolicyForObjectLambdaResponse(policy.map(value => value))
    def policy: Option[ObjectLambdaPolicy]
    def getPolicy: ZIO[Any, AwsError, ObjectLambdaPolicy] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
  ) extends zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse.ReadOnly {
    override val policy: Option[ObjectLambdaPolicy] = scala
      .Option(impl.policy())
      .map(value =>
        zio.aws.s3control.model.primitives.ObjectLambdaPolicy(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
  ): zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-s3control_3-5.17.184.1-sources.jar: zio/aws/s3control/model/GetAccessPointPolicyForObjectLambdaResponse.scala <==
package zio.aws.s3control.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.s3control.model.primitives.ObjectLambdaPolicy
import scala.jdk.CollectionConverters.*
final case class GetAccessPointPolicyForObjectLambdaResponse(
    policy: Optional[ObjectLambdaPolicy] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse = {
    import GetAccessPointPolicyForObjectLambdaResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
      .builder()
      .optionallyWith(
        policy.map(value => ObjectLambdaPolicy.unwrap(value): java.lang.String)
      )(_.policy)
      .build()
  }
  def asReadOnly
      : zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse.ReadOnly =
    zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
      .wrap(buildAwsValue())
}
object GetAccessPointPolicyForObjectLambdaResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse =
      zio.aws.s3control.model
        .GetAccessPointPolicyForObjectLambdaResponse(policy.map(value => value))
    def policy: Optional[ObjectLambdaPolicy]
    def getPolicy: ZIO[Any, AwsError, ObjectLambdaPolicy] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
  ) extends zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse.ReadOnly {
    override val policy: Optional[ObjectLambdaPolicy] = zio.aws.core.internal
      .optionalFromNullable(impl.policy())
      .map(value =>
        zio.aws.s3control.model.primitives.ObjectLambdaPolicy(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3control.model.GetAccessPointPolicyForObjectLambdaResponse
  ): zio.aws.s3control.model.GetAccessPointPolicyForObjectLambdaResponse.ReadOnly =
    new Wrapper(impl)
}
